@@ -8,6 +8,7 @@ from limic.select import CONFIG as SELECT_CONFIG
 from limic.length import CONFIG as LENGTH_CONFIG
 from limic.fill import CONFIG as FILL_CONFIG
 from limic.extract import CONFIG as EXTRACT_CONFIG
+from limic.condense import CONFIG as CONDENSE_CONFIG
 from limic.render import CONFIG as RENDER_CONFIG
 from limic.serve import CONFIG as SERVE_CONFIG
 from limic.test import CONFIG as TEST_CONFIG
@@ -25,6 +26,7 @@ CONFIG = [
     ("length",{'help':"Compute total length of non-air edges.",'args':LENGTH_CONFIG}),
     ("fill",{'help':"Fill a cache with map data.",'args':FILL_CONFIG}),
     ("extract",{'help':"Extract NX graph from cache with map data.",'args':EXTRACT_CONFIG}),
+    ("condense",{'help':"Condense linear segments", 'args':CONDENSE_CONFIG}),
     ("render",{'help':"Render graphs to HTML",'args':RENDER_CONFIG}),
     ("serve",{'help':"Serve interactive routing map",'args':SERVE_CONFIG}),
     ("test",{'help':"Extensive self tests.",'args':TEST_CONFIG}),
