@@ -146,7 +146,10 @@ def astar_nx(g,source_id=None,target_id=None):
         #assert(target==y)
         return haversine_distance(longx=x[2],latx=x[1],longy=targetlong,laty=targetlat)
     try:
-        path = astar_path(g,source,target,heuristic=distance)
+        if 'paths' in g.graph and g.graph['paths']:
+            path = g.graph['paths'][source][target]
+        else:
+            path = astar_path(g,source,target,heuristic=distance)
         cost = dist = 0.0
         dpath = [(cost,dist,False)+path[0]]
         for i in range(1,len(path)):
@@ -175,8 +178,7 @@ def route_nx(file_name,source_id=None,target_id=None,out_file=None,visualize=Fal
     
 def astar_cnx(g,source_id=None,target_id=None):
     from limic.util import locate_by_id, distance
-    #TODO handle locate_by_id correctly by constructing ids?
-    cs,node2closest,node2c = g
+    cs,node2closest,node2c = g.cs,g.node2closest,g.node2c
     if isinstance(source_id,tuple) and isinstance(target_id,tuple):
         source, target = source_id[0], target_id[0]
     else:
